@@ -50,7 +50,7 @@ if typing.TYPE_CHECKING:  # pragma: no cover
     import wheel.wheelfile  # noqa: F401
 
 
-__version__ = '0.7.0'
+__version__ = '0.8.0'
 
 
 class _depstr:
@@ -233,7 +233,7 @@ class _WheelBuilder():
         origin file and the Meson destination path.
         """
         warnings.warn('Using heuristics to map files to wheel, this may result in incorrect locations')
-        sys_vars = sysconfig.get_config_vars()
+        sys_vars = sysconfig.get_config_vars().copy()
         sys_vars['base'] = sys_vars['platbase'] = sys.base_prefix
         sys_paths = sysconfig.get_paths(vars=sys_vars)
         # Try to map to Debian dist-packages
@@ -672,7 +672,19 @@ class Project():
             return 'any'
         # XXX: Choose the sysconfig platform here and let something like auditwheel
         #      fix it later if there are system dependencies (eg. replace it with a manylinux tag)
-        return sysconfig.get_platform().replace('-', '_').replace('.', '_')
+        platform_ = sysconfig.get_platform()
+        parts = platform_.split('-')
+        if parts[0] == 'macosx' and parts[1] in ('11', '12'):
+            # Workaround for bug where pypa/packaging does not consider macOS
+            # tags without minor versions valid. Some Python flavors (Homebrew
+            # for example) on macOS started to do this in version 11, and
+            # pypa/packaging should handle things correctly from version 13 and
+            # forward, so we will add a 0 minor version to MacOS 11 and 12.
+            # https://github.com/FFY00/meson-python/issues/91
+            # https://github.com/pypa/packaging/issues/578
+            parts[1] += '.0'
+            platform_ = '-'.join(parts)
+        return platform_.replace('-', '_').replace('.', '_')
 
     def _calculate_file_abi_tag_heuristic_windows(self, filename: str) -> Optional[mesonpy._tags.Tag]:
         """Try to calculate the Windows tag from the Python extension file name."""
@@ -750,7 +762,9 @@ class Project():
                 #      See https://github.com/FFY00/meson-python/issues/95
                 #      Meson bug: https://github.com/mesonbuild/meson/issues/10601
                 from_heuristic = False
-                platlib = sysconfig.get_path('platlib')
+                sys_vars = sysconfig.get_config_vars().copy()
+                sys_vars['base'] = sys_vars['platbase'] = sys.base_prefix
+                platlib = sysconfig.get_path('platlib', vars=sys_vars)
                 if platlib and mesonpy._compat.is_relative_to(destination, platlib):
                     from_heuristic = True
                 else:
@@ -764,7 +778,7 @@ class Project():
                         'to be mapped to platlib, but it was used to calculate '
                         f'the ABI tag: {destination}'
                     )
-                files_by_tag[tag] += file
+                files_by_tag[tag].append(file)
 
         return files_by_tag
 
